@@ -6,7 +6,7 @@ use 5.008001;
 use Alien::Build::Plugin;
 
 # ABSTRACT: Plugin to extract links from HTML using Mojo::DOM or Mojo::DOM58
-our $VERSION = '1.96'; # VERSION
+our $VERSION = '2.00'; # VERSION
 
 
 sub _load ($;$)
@@ -37,11 +37,13 @@ sub init
   $meta->add_requires('share' => 'URI' => 0);
   $meta->add_requires('share' => 'URI::Escape' => 0);
 
-  if($self->_class eq 'Mojo::DOM58')
+  my $class = $meta->prop->{plugin_decode_mojo_class} ||= $self->_class;
+
+  if($class eq 'Mojo::DOM58')
   {
     $meta->add_requires('share' => 'Mojo::DOM58' => '1.00');
   }
-  elsif($self->_class eq 'Mojo::DOM')
+  elsif($class eq 'Mojo::DOM')
   {
     $meta->add_requires('share' => 'Mojolicious' => '7.00');
     $meta->add_requires('share' => 'Mojo::DOM'   => '0');
@@ -57,7 +59,7 @@ sub init
     die "do not know how to decode @{[ $res->{type} ]}"
       unless $res->{type} eq 'html';
 
-    my $dom = $self->_class->new($res->{content});
+    my $dom = $class->new($res->{content});
 
     my $base = URI->new($res->{base});
 
@@ -103,7 +105,7 @@ Alien::Build::Plugin::Decode::Mojo - Plugin to extract links from HTML using Moj
 
 =head1 VERSION
 
-version 1.96
+version 2.00
 
 =head1 SYNOPSIS
 
